@@ -221,102 +221,100 @@ Col<eT>::operator=(const std::vector<eT>& x)
 
 
 
-#if defined(ARMA_USE_CXX11)
+template<typename eT>
+inline
+Col<eT>::Col(const std::initializer_list<eT>& list)
+  : Mat<eT>(arma_vec_indicator(), 1)
+  {
+  arma_extra_debug_sigprint();
   
-  template<typename eT>
-  inline
-  Col<eT>::Col(const std::initializer_list<eT>& list)
-    : Mat<eT>(arma_vec_indicator(), 1)
+  (*this).operator=(list);
+  }
+
+
+
+template<typename eT>
+inline
+Col<eT>&
+Col<eT>::operator=(const std::initializer_list<eT>& list)
+  {
+  arma_extra_debug_sigprint();
+  
+  Mat<eT> tmp(list);
+  
+  arma_debug_check( ((tmp.n_elem > 0) && (tmp.is_vec() == false)), "Mat::init(): requested size is not compatible with column vector layout" );
+  
+  access::rw(tmp.n_rows) = tmp.n_elem;
+  access::rw(tmp.n_cols) = 1;
+  
+  (*this).steal_mem(tmp);
+  
+  return *this;
+  }
+
+
+
+template<typename eT>
+inline
+Col<eT>::Col(Col<eT>&& X)
+  : Mat<eT>(arma_vec_indicator(), 1)
+  {
+  arma_extra_debug_sigprint(arma_str::format("this = %x   X = %x") % this % &X);
+  
+  access::rw(Mat<eT>::n_rows)  = X.n_rows;
+  access::rw(Mat<eT>::n_cols)  = 1;
+  access::rw(Mat<eT>::n_elem)  = X.n_elem;
+  access::rw(Mat<eT>::n_alloc) = X.n_alloc;
+  
+  if( (X.n_alloc > arma_config::mat_prealloc) || (X.mem_state == 1) || (X.mem_state == 2) )
     {
-    arma_extra_debug_sigprint();
+    access::rw(Mat<eT>::mem_state) = X.mem_state;
+    access::rw(Mat<eT>::mem)       = X.mem;
     
-    (*this).operator=(list);
+    access::rw(X.n_rows)    = 0;
+    access::rw(X.n_cols)    = 1;
+    access::rw(X.n_elem)    = 0;
+    access::rw(X.n_alloc)   = 0;
+    access::rw(X.mem_state) = 0;
+    access::rw(X.mem)       = nullptr;
     }
-  
-  
-  
-  template<typename eT>
-  inline
-  Col<eT>&
-  Col<eT>::operator=(const std::initializer_list<eT>& list)
+  else  // condition: (X.n_alloc <= arma_config::mat_prealloc) || (X.mem_state == 0) || (X.mem_state == 3)
     {
-    arma_extra_debug_sigprint();
+    (*this).init_cold();
     
-    Mat<eT> tmp(list);
+    arrayops::copy( (*this).memptr(), X.mem, X.n_elem );
     
-    arma_debug_check( ((tmp.n_elem > 0) && (tmp.is_vec() == false)), "Mat::init(): requested size is not compatible with column vector layout" );
-    
-    access::rw(tmp.n_rows) = tmp.n_elem;
-    access::rw(tmp.n_cols) = 1;
-    
-    (*this).steal_mem(tmp);
-    
-    return *this;
-    }
-  
-  
-  
-  template<typename eT>
-  inline
-  Col<eT>::Col(Col<eT>&& X)
-    : Mat<eT>(arma_vec_indicator(), 1)
-    {
-    arma_extra_debug_sigprint(arma_str::format("this = %x   X = %x") % this % &X);
-    
-    access::rw(Mat<eT>::n_rows) = X.n_rows;
-    access::rw(Mat<eT>::n_cols) = 1;
-    access::rw(Mat<eT>::n_elem) = X.n_elem;
-    
-    if( ((X.mem_state == 0) && (X.n_elem > arma_config::mat_prealloc)) || (X.mem_state == 1) || (X.mem_state == 2) )
+    if( (X.mem_state == 0) && (X.n_alloc <= arma_config::mat_prealloc) )
       {
-      access::rw(Mat<eT>::mem_state) = X.mem_state;
-      access::rw(Mat<eT>::mem)       = X.mem;
-      
-      access::rw(X.n_rows)    = 0;
-      access::rw(X.n_cols)    = 1;
-      access::rw(X.n_elem)    = 0;
-      access::rw(X.mem_state) = 0;
-      access::rw(X.mem)       = 0;
-      }
-    else
-      {
-      (*this).init_cold();
-      
-      arrayops::copy( (*this).memptr(), X.mem, X.n_elem );
-      
-      if( (X.mem_state == 0) && (X.n_elem <= arma_config::mat_prealloc) )
-        {
-        access::rw(X.n_rows) = 0;
-        access::rw(X.n_cols) = 1;
-        access::rw(X.n_elem) = 0;
-        access::rw(X.mem)    = 0;
-        }
+      access::rw(X.n_rows)  = 0;
+      access::rw(X.n_cols)  = 1;
+      access::rw(X.n_elem)  = 0;
+      access::rw(X.mem)     = nullptr;
       }
     }
+  }
+
+
+
+template<typename eT>
+inline
+Col<eT>&
+Col<eT>::operator=(Col<eT>&& X)
+  {
+  arma_extra_debug_sigprint(arma_str::format("this = %x   X = %x") % this % &X);
   
+  (*this).steal_mem(X);
   
-  
-  template<typename eT>
-  inline
-  Col<eT>&
-  Col<eT>::operator=(Col<eT>&& X)
+  if( (X.mem_state == 0) && (X.n_alloc <= arma_config::mat_prealloc) && (this != &X) )
     {
-    arma_extra_debug_sigprint(arma_str::format("this = %x   X = %x") % this % &X);
-    
-    (*this).steal_mem(X);
-    
-    if( (X.mem_state == 0) && (X.n_elem <= arma_config::mat_prealloc) && (this != &X) )
-      {
-      access::rw(X.n_rows) = 0;
-      access::rw(X.n_cols) = 1;
-      access::rw(X.n_elem) = 0;
-      access::rw(X.mem)    = 0;
-      }
-    
-    return *this;
+    access::rw(X.n_rows) = 0;
+    access::rw(X.n_cols) = 1;
+    access::rw(X.n_elem) = 0;
+    access::rw(X.mem)    = nullptr;
     }
   
-#endif
+  return *this;
+  }
 
 
 
@@ -506,6 +504,7 @@ Col<eT>::operator=(const subview_cube<eT>& X)
 
 template<typename eT>
 inline
+arma_cold
 mat_injector< Col<eT> >
 Col<eT>::operator<<(const eT val)
   {
@@ -561,7 +560,7 @@ Col<eT>::row(const uword in_row1)
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( (in_row1 >= Mat<eT>::n_rows), "Col::row(): indices out of bounds or incorrectly used");
+  arma_debug_check( (in_row1 >= Mat<eT>::n_rows), "Col::row(): indices out of bounds or incorrectly used" );
   
   return subview_col<eT>(*this, 0, in_row1, 1);
   }
@@ -575,7 +574,7 @@ Col<eT>::row(const uword in_row1) const
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( (in_row1 >= Mat<eT>::n_rows), "Col::row(): indices out of bounds or incorrectly used");
+  arma_debug_check( (in_row1 >= Mat<eT>::n_rows), "Col::row(): indices out of bounds or incorrectly used" );
   
   return subview_col<eT>(*this, 0, in_row1, 1);
   }
@@ -589,7 +588,7 @@ Col<eT>::rows(const uword in_row1, const uword in_row2)
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( ( (in_row1 > in_row2) || (in_row2 >= Mat<eT>::n_rows) ), "Col::rows(): indices out of bounds or incorrectly used");
+  arma_debug_check( ( (in_row1 > in_row2) || (in_row2 >= Mat<eT>::n_rows) ), "Col::rows(): indices out of bounds or incorrectly used" );
   
   const uword subview_n_rows = in_row2 - in_row1 + 1;
   
@@ -605,7 +604,7 @@ Col<eT>::rows(const uword in_row1, const uword in_row2) const
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( ( (in_row1 > in_row2) || (in_row2 >= Mat<eT>::n_rows) ), "Col::rows(): indices out of bounds or incorrectly used");
+  arma_debug_check( ( (in_row1 > in_row2) || (in_row2 >= Mat<eT>::n_rows) ), "Col::rows(): indices out of bounds or incorrectly used" );
   
   const uword subview_n_rows = in_row2 - in_row1 + 1;
   
@@ -621,7 +620,7 @@ Col<eT>::subvec(const uword in_row1, const uword in_row2)
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( ( (in_row1 > in_row2) || (in_row2 >= Mat<eT>::n_rows) ), "Col::subvec(): indices out of bounds or incorrectly used");
+  arma_debug_check( ( (in_row1 > in_row2) || (in_row2 >= Mat<eT>::n_rows) ), "Col::subvec(): indices out of bounds or incorrectly used" );
   
   const uword subview_n_rows = in_row2 - in_row1 + 1;
   
@@ -637,7 +636,7 @@ Col<eT>::subvec(const uword in_row1, const uword in_row2) const
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( ( (in_row1 > in_row2) || (in_row2 >= Mat<eT>::n_rows) ), "Col::subvec(): indices out of bounds or incorrectly used");
+  arma_debug_check( ( (in_row1 > in_row2) || (in_row2 >= Mat<eT>::n_rows) ), "Col::subvec(): indices out of bounds or incorrectly used" );
   
   const uword subview_n_rows = in_row2 - in_row1 + 1;
   
@@ -685,7 +684,7 @@ Col<eT>::subvec(const span& row_span)
   const uword in_row2       =                          row_span.b;
   const uword subvec_n_rows = row_all ? local_n_rows : in_row2 - in_row1 + 1;
 
-  arma_debug_check( ( row_all ? false : ((in_row1 > in_row2) || (in_row2 >= local_n_rows)) ), "Col::subvec(): indices out of bounds or incorrectly used");
+  arma_debug_check( ( row_all ? false : ((in_row1 > in_row2) || (in_row2 >= local_n_rows)) ), "Col::subvec(): indices out of bounds or incorrectly used" );
   
   return subview_col<eT>(*this, 0, in_row1, subvec_n_rows);
   }
@@ -707,7 +706,7 @@ Col<eT>::subvec(const span& row_span) const
   const uword in_row2       =                          row_span.b;
   const uword subvec_n_rows = row_all ? local_n_rows : in_row2 - in_row1 + 1;
 
-  arma_debug_check( ( row_all ? false : ((in_row1 > in_row2) || (in_row2 >= local_n_rows)) ), "Col::subvec(): indices out of bounds or incorrectly used");
+  arma_debug_check( ( row_all ? false : ((in_row1 > in_row2) || (in_row2 >= local_n_rows)) ), "Col::subvec(): indices out of bounds or incorrectly used" );
   
   return subview_col<eT>(*this, 0, in_row1, subvec_n_rows);
   }
@@ -777,7 +776,7 @@ Col<eT>::head(const uword N)
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( (N > Mat<eT>::n_rows), "Col::head(): size out of bounds");
+  arma_debug_check( (N > Mat<eT>::n_rows), "Col::head(): size out of bounds" );
   
   return subview_col<eT>(*this, 0, 0, N);
   }
@@ -791,7 +790,7 @@ Col<eT>::head(const uword N) const
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( (N > Mat<eT>::n_rows), "Col::head(): size out of bounds");
+  arma_debug_check( (N > Mat<eT>::n_rows), "Col::head(): size out of bounds" );
   
   return subview_col<eT>(*this, 0, 0, N);
   }
@@ -805,7 +804,7 @@ Col<eT>::tail(const uword N)
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( (N > Mat<eT>::n_rows), "Col::tail(): size out of bounds");
+  arma_debug_check( (N > Mat<eT>::n_rows), "Col::tail(): size out of bounds" );
   
   const uword start_row = Mat<eT>::n_rows - N;
   
@@ -821,7 +820,7 @@ Col<eT>::tail(const uword N) const
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( (N > Mat<eT>::n_rows), "Col::tail(): size out of bounds");
+  arma_debug_check( (N > Mat<eT>::n_rows), "Col::tail(): size out of bounds" );
   
   const uword start_row = Mat<eT>::n_rows - N;
   
@@ -886,7 +885,7 @@ Col<eT>::shed_row(const uword row_num)
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( row_num >= Mat<eT>::n_rows, "Col::shed_row(): index out of bounds");
+  arma_debug_check( row_num >= Mat<eT>::n_rows, "Col::shed_row(): index out of bounds" );
   
   shed_rows(row_num, row_num);
   }
@@ -930,6 +929,20 @@ Col<eT>::shed_rows(const uword in_row1, const uword in_row2)
 
 
 
+//! remove specified rows
+template<typename eT>
+template<typename T1>
+inline
+void
+Col<eT>::shed_rows(const Base<uword, T1>& indices)
+  {
+  arma_extra_debug_sigprint();
+  
+  Mat<eT>::shed_rows(indices);
+  }
+
+
+
 //! insert N rows at the specified row position,
 //! optionally setting the elements of the inserted rows to zero
 template<typename eT>
@@ -945,7 +958,7 @@ Col<eT>::insert_rows(const uword row_num, const uword N, const bool set_to_zero)
   const uword B_n_rows = t_n_rows - row_num;
   
   // insertion at row_num == n_rows is in effect an append operation
-  arma_debug_check( (row_num > t_n_rows), "Col::insert_rows(): index out of bounds");
+  arma_debug_check( (row_num > t_n_rows), "Col::insert_rows(): index out of bounds" );
   
   if(N > 0)
     {
@@ -1041,7 +1054,7 @@ Col<eT>::begin_row(const uword row_num)
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( (row_num >= Mat<eT>::n_rows), "Col::begin_row(): index out of bounds");
+  arma_debug_check( (row_num >= Mat<eT>::n_rows), "Col::begin_row(): index out of bounds" );
   
   return Mat<eT>::memptr() + row_num;
   }
@@ -1055,7 +1068,7 @@ Col<eT>::begin_row(const uword row_num) const
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( (row_num >= Mat<eT>::n_rows), "Col::begin_row(): index out of bounds");
+  arma_debug_check( (row_num >= Mat<eT>::n_rows), "Col::begin_row(): index out of bounds" );
   
   return Mat<eT>::memptr() + row_num;
   }
@@ -1069,7 +1082,7 @@ Col<eT>::end_row(const uword row_num)
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( (row_num >= Mat<eT>::n_rows), "Col::end_row(): index out of bounds");
+  arma_debug_check( (row_num >= Mat<eT>::n_rows), "Col::end_row(): index out of bounds" );
   
   return Mat<eT>::memptr() + row_num + 1;
   }
@@ -1083,7 +1096,7 @@ Col<eT>::end_row(const uword row_num) const
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( (row_num >= Mat<eT>::n_rows), "Col::end_row(): index out of bounds");
+  arma_debug_check( (row_num >= Mat<eT>::n_rows), "Col::end_row(): index out of bounds" );
   
   return Mat<eT>::memptr() + row_num + 1;
   }
@@ -1288,43 +1301,39 @@ Col<eT>::fixed<fixed_n_elem>::operator=(const subview_cube<eT>& X)
 
 
 
-#if defined(ARMA_USE_CXX11)
+template<typename eT>
+template<uword fixed_n_elem>
+inline
+Col<eT>::fixed<fixed_n_elem>::fixed(const std::initializer_list<eT>& list)
+  : Col<eT>( arma_fixed_indicator(), fixed_n_elem, ((use_extra) ? mem_local_extra : Mat<eT>::mem_local) )
+  {
+  arma_extra_debug_sigprint_this(this);
   
-  template<typename eT>
-  template<uword fixed_n_elem>
-  inline
-  Col<eT>::fixed<fixed_n_elem>::fixed(const std::initializer_list<eT>& list)
-    : Col<eT>( arma_fixed_indicator(), fixed_n_elem, ((use_extra) ? mem_local_extra : Mat<eT>::mem_local) )
-    {
-    arma_extra_debug_sigprint_this(this);
-    
-    (*this).operator=(list);
-    }
+  (*this).operator=(list);
+  }
+
+
+
+template<typename eT>
+template<uword fixed_n_elem>
+inline
+Col<eT>&
+Col<eT>::fixed<fixed_n_elem>::operator=(const std::initializer_list<eT>& list)
+  {
+  arma_extra_debug_sigprint();
   
+  const uword N = uword(list.size());
   
+  arma_debug_check( (N > fixed_n_elem), "Col::fixed: initialiser list is too long" );
   
-  template<typename eT>
-  template<uword fixed_n_elem>
-  inline
-  Col<eT>&
-  Col<eT>::fixed<fixed_n_elem>::operator=(const std::initializer_list<eT>& list)
-    {
-    arma_extra_debug_sigprint();
-    
-    const uword N = uword(list.size());
-    
-    arma_debug_check( (N > fixed_n_elem), "Col::fixed: initialiser list is too long" );
-    
-    eT* this_mem = (*this).memptr();
-    
-    arrayops::copy( this_mem, list.begin(), N );
-    
-    for(uword iq=N; iq < fixed_n_elem; ++iq) { this_mem[iq] = eT(0); }
-    
-    return *this;
-    }
+  eT* this_mem = (*this).memptr();
   
-#endif
+  arrayops::copy( this_mem, list.begin(), N );
+  
+  for(uword iq=N; iq < fixed_n_elem; ++iq) { this_mem[iq] = eT(0); }
+  
+  return *this;
+  }
 
 
 
@@ -1535,7 +1544,7 @@ arma_warn_unused
 eT&
 Col<eT>::fixed<fixed_n_elem>::operator() (const uword ii)
   {
-  arma_debug_check( (ii >= fixed_n_elem), "Col::operator(): index out of bounds");
+  arma_debug_check( (ii >= fixed_n_elem), "Col::operator(): index out of bounds" );
   
   return (use_extra) ? mem_local_extra[ii] : Mat<eT>::mem_local[ii];
   }
@@ -1549,7 +1558,7 @@ arma_warn_unused
 const eT&
 Col<eT>::fixed<fixed_n_elem>::operator() (const uword ii) const
   {
-  arma_debug_check( (ii >= fixed_n_elem), "Col::operator(): index out of bounds");
+  arma_debug_check( (ii >= fixed_n_elem), "Col::operator(): index out of bounds" );
   
   return (use_extra) ? mem_local_extra[ii] : Mat<eT>::mem_local[ii];
   }
