@@ -68,6 +68,9 @@ struct SpBase
   arma_cold inline void raw_print_dense(                           const std::string extra_text = "") const;
   arma_cold inline void raw_print_dense(std::ostream& user_stream, const std::string extra_text = "") const;
   
+  arma_cold inline void brief_print(                           const std::string extra_text = "") const;
+  arma_cold inline void brief_print(std::ostream& user_stream, const std::string extra_text = "") const;
+  
   inline arma_warn_unused elem_type min() const;
   inline arma_warn_unused elem_type max() const;
   
@@ -86,18 +89,22 @@ struct SpBase
   inline arma_warn_unused bool is_hermitian() const;
   inline arma_warn_unused bool is_hermitian(const typename get_pod_type<elem_type>::result tol) const;
   
-  inline arma_warn_unused bool is_empty()  const;
-  inline arma_warn_unused bool is_square() const;
-  inline arma_warn_unused bool is_vec()    const;
-  inline arma_warn_unused bool is_colvec() const;
-  inline arma_warn_unused bool is_rowvec() const;
-  inline arma_warn_unused bool is_finite() const;
-  inline arma_warn_unused bool has_inf()   const;
-  inline arma_warn_unused bool has_nan()   const;
+  inline arma_warn_unused bool is_zero(const typename get_pod_type<elem_type>::result tol = 0) const;
   
-  inline const SpOp<derived,spop_vectorise_col> as_col() const;
-  inline const SpOp<derived,spop_vectorise_row> as_row() const;
+  inline arma_warn_unused bool is_trimatu() const;
+  inline arma_warn_unused bool is_trimatl() const;
+  inline arma_warn_unused bool is_diagmat() const;
+  inline arma_warn_unused bool is_empty()   const;
+  inline arma_warn_unused bool is_square()  const;
+  inline arma_warn_unused bool is_vec()     const;
+  inline arma_warn_unused bool is_colvec()  const;
+  inline arma_warn_unused bool is_rowvec()  const;
+  inline arma_warn_unused bool is_finite()  const;
+  inline arma_warn_unused bool has_inf()    const;
+  inline arma_warn_unused bool has_nan()    const;
   
+  inline arma_warn_unused const SpOp<derived,spop_vectorise_col> as_col() const;
+  inline arma_warn_unused const SpOp<derived,spop_vectorise_row> as_row() const;
   };
 
 
