@@ -23,6 +23,18 @@
 #endif
 
 
+// workaround for issue on macOS 11 and/or AppleClang 12.0
+// see https://gitlab.com/conradsnicta/armadillo-code/-/issues/173
+// the workaround is here instead of CMakeLists.txt
+// to ensure that the armadillo runtime library has arma_rng_cxx11_instance
+// for already compiled programs running on earlier versions of macOS
+#if defined(__APPLE__) || defined(__apple_build_version__)
+  #if !defined(ARMA_DONT_DISABLE_EXTERN_RNG)
+    #undef ARMA_USE_EXTERN_RNG
+  #endif
+#endif
+
+
 #if defined(ARMA_USE_EXTERN_RNG)
   extern thread_local arma_rng_cxx11 arma_rng_cxx11_instance;
   // namespace { thread_local arma_rng_cxx11 arma_rng_cxx11_instance; }
@@ -254,20 +266,9 @@ struct arma_rng::randu
   void
   fill(eT* mem, const uword N)
     {
-    uword j;
-    
-    for(j=1; j < N; j+=2)
+    for(uword i=0; i < N; ++i)
       {
-      const eT tmp_i = eT( arma_rng::randu<eT>() );
-      const eT tmp_j = eT( arma_rng::randu<eT>() );
-      
-      (*mem) = tmp_i;  mem++;
-      (*mem) = tmp_j;  mem++;
-      }
-    
-    if((j-1) < N)
-      {
-      (*mem) = eT( arma_rng::randu<eT>() );
+      mem[i] = eT( arma_rng::randu<eT>() );
       }
     }
   };
@@ -326,7 +327,7 @@ struct arma_rng::randn
     }
   
   
-  arma_inline
+  inline
   static
   void
   dual_val(eT& out1, eT& out2)
@@ -441,6 +442,27 @@ struct arma_rng::randn< std::complex<T> >
     }
   
   
+  inline
+  static
+  void
+  dual_val(std::complex<T>& out1, std::complex<T>& out2)
+    {
+    #if defined(_MSC_VER)
+      T a;
+      T b;
+    #else
+      T a(0);
+      T b(0);
+    #endif
+    
+    arma_rng::randn<T>::dual_val(a,b);
+    out1 = std::complex<T>(a,b);
+    
+    arma_rng::randn<T>::dual_val(a,b);
+    out2 = std::complex<T>(a,b);
+    }
+  
+  
   inline
   static
   void
