@@ -1,11 +1,17 @@
-// Copyright (C) 2008-2014 National ICT Australia (NICTA)
+// Copyright 2008-2016 Conrad Sanderson (http://conradsanderson.id.au)
+// Copyright 2008-2016 National ICT Australia (NICTA)
 // 
-// This Source Code Form is subject to the terms of the Mozilla Public
-// License, v. 2.0. If a copy of the MPL was not distributed with this
-// file, You can obtain one at http://mozilla.org/MPL/2.0/.
-// -------------------------------------------------------------------
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+// http://www.apache.org/licenses/LICENSE-2.0
 // 
-// Written by Conrad Sanderson - http://conradsanderson.id.au
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
+// ------------------------------------------------------------------------
 
 
 //! \addtogroup op_dot
@@ -15,11 +21,12 @@
 //! dot product operation 
 
 class op_dot
+  : public traits_op_default
   {
   public:
   
   template<typename eT>
-  arma_hot arma_inline static
+  arma_inline static
   typename arma_not_cx<eT>::result
   direct_dot_arma(const uword n_elem, const eT* const A, const eT* const B);
   
@@ -60,6 +67,7 @@ class op_dot
 //! normalised dot product operation 
 
 class op_norm_dot
+  : public traits_op_default
   {
   public:
   
@@ -73,6 +81,7 @@ class op_norm_dot
 //! complex conjugate dot product operation
 
 class op_cdot
+  : public traits_op_default
   {
   public:
   
@@ -95,6 +104,7 @@ class op_cdot
 
 
 class op_dot_mixed
+  : public traits_op_default
   {
   public:
   
